@@ -2,9 +2,6 @@
 
 //! All-purpose [`assert!(...)`](macro.assert.html) and [`check!(...)`](macro.check.html) macros, inspired by [Catch2](https://github.com/catchorg/Catch2).
 //!
-//! This crate is currently a work in progress.
-//! It relies on a nightly compiler with the `proc_macro_span` features.
-//!
 //! # Why these macros?
 //!
 //! These macros offer some benefits over the assertions from the standard library:
@@ -25,7 +22,7 @@
 //! check!(6 + 1 <= 2 * 3);
 //! ```
 //!
-//! ![Assertion error](https://github.com/de-vri-es/assert2-rs/raw/406f0d065e56db6e3f94c6e2d34b0f2c5b8f0f9f/binary-operator.png)
+//! ![Assertion error](https://github.com/de-vri-es/assert2-rs/raw/2db44c46e4580ec87d2881a698815e1ec5fcdf3f/binary-operator.png)
 //!
 //! ----------
 //!
@@ -34,7 +31,7 @@
 //! check!(true && false);
 //! ```
 //!
-//! ![Assertion error](https://github.com/de-vri-es/assert2-rs/raw/406f0d065e56db6e3f94c6e2d34b0f2c5b8f0f9f/boolean-expression.png)
+//! ![Assertion error](https://github.com/de-vri-es/assert2-rs/raw/2db44c46e4580ec87d2881a698815e1ec5fcdf3f/boolean-expression.png)
 //!
 //! ----------
 //!
@@ -44,18 +41,26 @@
 //! check!(let Ok(_) = File::open("/non/existing/file"));
 //! ```
 //!
-//! ![Assertion error](https://github.com/de-vri-es/assert2-rs/raw/406f0d065e56db6e3f94c6e2d34b0f2c5b8f0f9f/pattern-match.png)
+//! ![Assertion error](https://github.com/de-vri-es/assert2-rs/raw/2db44c46e4580ec87d2881a698815e1ec5fcdf3f/pattern-match.png)
 //!
 //! # `assert` vs `check`
 //! The crate provides two macros: `check!(...)` and `assert!(...)`.
-//! The main difference is that `check` doesn't immediately panic.
+//! The main difference is that `check` is really intended for test cases and doesn't immediately panic.
 //! Instead, it will print the assertion error and fail the test.
 //! This allows you to run multiple checks and can help to determine the reason of a test failure more easily.
+//! The `assert` macro on the other hand simply prints the error and panics,
+//! and can be used outside of tests just as well.
 //!
 //! Currently, `check` uses a scope guard to delay the panic until the current scope ends.
 //! Ideally, `check` doesn't panic at all, but only signals that a test case has failed.
 //! If this becomes possible in the future, the `check` macro will change, so **you should not rely on `check` to panic**.
 //!
+//! # Difference between stable and nightly.
+//! If available, the crate uses the `proc_macro_span` feature to get the original source code.
+//! On stable and beta, it falls back to stringifying the expression.
+//! This makes the output a bit more readable on nightly,
+//! but the differences are limited to the displayed expression.
+//!
 //! # Controlling colored output.
 //!
 //! You can force colored output on or off by setting the `CLICOLOR` environment variable.
@@ -90,7 +95,6 @@ pub use assert2_macros::check_impl;
 macro_rules! assert {
 	($($tokens:tt)*) => {
 		if let Err(()) = ::assert2::check_impl!("assert", $($tokens)*) {
-			eprintln!();
 			panic!("assertion failed");
 		}
 	}
@@ -125,7 +129,6 @@ macro_rules! check {
 		let _guard = match ::assert2::check_impl!("check", $($tokens)*) {
 			Ok(_) => None,
 			Err(_) => {
-				eprintln!();
 				Some(::assert2::FailGuard(|| panic!("check failed")))
 			},
 		};
